public class UE11Aufgabe15 {

	public static void main(String[] args) {
		EMailSimulation simulation = new EMailSimulation();
		simulation.personenAnmeldung();
		simulation.emailVerkehr();
		simulation.mailboxAbfrage();
	}

}

class Person {
	String name; // Name
	String emailAdresse; // EMail-Adresse
	Mailbox mailbox; // persoenliche Mailbox

	public Person(String name, String adresse) {
		this.name = name;
		this.emailAdresse = adresse;
		this.mailbox = new Mailbox(this);
	}

	// neue EMail-Adresse
	public void setEMailAdresse(String adresse) {
		this.emailAdresse = adresse;
	}

	public String getName() {
		return this.name;
	}

	public String getEMailAdresse() {
		return this.emailAdresse;
	}

	public Mailbox getMailbox() {
		return this.mailbox;
	}

	public void emailZuschicken(EMail mail) {
		this.mailbox.neueEMail(mail);
	}
}

class EMail {
	Person sender; // Sender
	Person empfaenger; // Empfaenger
	String subject; // Subject der EMail
	String inhalt; // der eigentliche Inhalt

	public EMail(Person from, Person to, String title, String text) {
		this.sender = from;
		this.empfaenger = to;
		this.subject = title;
		this.inhalt = text;
	}

	public Person getSender() {
		return this.sender;
	}

	public Person getEmpfaenger() {
		return this.empfaenger;
	}

	public String getSubject() {
		return this.subject;
	}

	public String getInhalt() {
		return this.inhalt;
	}

	public void print() {
		IO.println("****** Begin EMail *****");
		IO.println("TO: " + this.empfaenger.getEMailAdresse() + "("
				+ this.empfaenger.getName() + ")");
		IO.println("FROM: " + this.sender.getEMailAdresse() + "("
				+ this.sender.getName() + ")");
		IO.println("SUBJECT: " + this.subject);
		IO.println("\n" + this.inhalt);
		IO.println("****** End EMail *****");
	}
}

class Mailbox {
	Person besitzer; // Besitzer der Mailbox
	EMail[] emails; // gespeicherte EMails
	int next;

	public Mailbox(Person besitzer, int maxGroesse) {
		this.besitzer = besitzer;
		this.emails = new EMail[maxGroesse];
		for (int i = 0; i < maxGroesse; i++) {
			this.emails[i] = null;
		}
		this.next = 0;

	}

	public Mailbox(Person besitzer) {
		this.besitzer = besitzer;
		this.emails = new EMail[100];
		for (int i = 0; i < this.emails.length; i++) {
			this.emails[i] = null;
		}
		this.next = 0;
	}

	public void neueEMail(EMail mail) {
		if (this.next < this.emails.length) {
			this.emails[this.next++] = mail;
		}
	}

	public boolean istLeer() {
		return this.next == 0;
	}

	public Person getBesitzer() {
		return this.besitzer;
	}

	public EMail[] getEmails() {
		return this.emails;
	}

	public int getAnzahlEmails() {
		return this.next;
	}
}

class EMailSimulation {

	Person[] personen; // Menge von Personen

	public EMailSimulation() {
		this.personen = null;
	}

	public void personenAnmeldung() {
		IO.println("Anmeldung");
		IO.println("---------");
		int anzahl = IO.readInt("Personenanzahl: ");
		this.personen = new Person[anzahl];
		for (int i = 0; i < anzahl; i++) {
			this.personen[i] = new Person(IO.readString("Name: "),
					IO.readString("EMail: "));
		}
	}

	public void emailVerkehr() {
		IO.println("EMailverkehr");
		IO.println("------------");
		boolean weiter = IO.readChar("Weitere EMail verschicken (j/n)?") == 'j';
		while (weiter) {
			String senderName = IO.readString("Sendername: ");
			Person sender = this.ermittlePerson(senderName);
			if (sender == null) {
				IO.println("Sender unbekannt!");
				continue;
			}
			String empfaengerName = IO.readString("Empfaengername: ");
			Person empfaenger = this.ermittlePerson(empfaengerName);
			if (empfaenger == null) {
				IO.println("Empfaenger unbekannt!");
				continue;
			}
			String subject = IO.readString("Subject: ");
			String inhalt = IO.readString("Text: ");

			EMail neueEMail = new EMail(sender, empfaenger, subject, inhalt);

			// EMail verschicken
			empfaenger.emailZuschicken(neueEMail);

			weiter = IO.readChar("Weitere EMail verschicken (j/n)?") == 'j';
		}

	}

	public void mailboxAbfrage() {
		IO.println("Mailboxabfrage");
		IO.println("--------------");
		boolean weiter = IO.readChar("Weitere Mailboxabfrage (j/n)?") == 'j';
		while (weiter) {
			String name = IO.readString("Name: ");
			Person mensch = this.ermittlePerson(name);
			if (mensch == null) {
				IO.println("Person unbekannt!");
				continue;
			}
			Mailbox box = mensch.getMailbox();
			if (box.istLeer()) {
				IO.println("Mailbox ist leer");
			} else {
				EMail[] emails = box.getEmails();
				for (int i = 0; i < box.getAnzahlEmails(); i++) {
					emails[i].print();
				}
			}
			weiter = IO.readChar("Weitere Mailboxabfrage (j/n)?") == 'j';
		}
	}

	public Person ermittlePerson(String name) {
		for (int i = 0; i < this.personen.length; i++) {
			if (this.personen[i].getName().equals(name)) {
				return this.personen[i];
			}
		}
		return null; // nicht vorhanden
	}
}
